//
//  TestContentViewController.m
//  SlidingMenu
//
//  Created by Matthew Brochstein on 5/7/12.
//  Copyright (c) 2012 . All rights reserved.
//

#import "TestContentViewController.h"
#import "ETRSlidingMenuViewController.h"

@interface TestContentViewController ()

@property (nonatomic, retain) UIButton *toggleButton;
@property (nonatomic, retain) UIScrollView *scrollView;

@end

@implementation TestContentViewController

@synthesize toggleButton = _toggleButton;
@synthesize scrollView = _scrollView;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nil bundle:nil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)dealloc
{
    
    [self.scrollView removeObserver:self forKeyPath:@"frame"];
    
    self.toggleButton = nil;
    self.scrollView = nil;
    [super dealloc];
}

- (void)viewDidLoad
{
    
    [super viewDidLoad];
    
    self.toggleButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [self.toggleButton setFrame:CGRectMake(10.0, 10.0, 60.0, 40.0)];
    [self.toggleButton setBackgroundColor:[UIColor blackColor]];
    [self.toggleButton addTarget:self.slidingMenuViewController action:@selector(toggleMenu) forControlEvents:UIControlEventTouchUpInside];
    [self.toggleButton setAutoresizingMask:UIViewAutoresizingFlexibleRightMargin|UIViewAutoresizingFlexibleBottomMargin];
    
    self.scrollView = [[[UIScrollView alloc] initWithFrame:self.view.bounds] autorelease];
    [self.scrollView setDelegate:self];
    [self.scrollView setBackgroundColor:[UIColor orangeColor]];
    [self.scrollView setShowsHorizontalScrollIndicator:YES];
    [self.scrollView setBounces:YES];
    [self.scrollView setAutoresizingMask:UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth];
    [self.view addSubview:self.scrollView];
    
    [self.scrollView addObserver:self forKeyPath:@"frame" options:0 context:nil];

    UIPanGestureRecognizer *panGestureRecognizer = [[[UIPanGestureRecognizer alloc] initWithTarget:self action:@selector(handlePan:)] autorelease];
    [panGestureRecognizer setDelegate:self];
    [self.toggleButton addGestureRecognizer:panGestureRecognizer];

    
    [self.view addSubview:_toggleButton];
    [self.view setAutoresizesSubviews:YES];
    
}

- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object change:(NSDictionary *)change context:(void *)context
{
    if ([keyPath isEqualToString:@"frame"]) {
        NSLog(@"Scroll view frame: %@", NSStringFromCGRect(self.scrollView.frame));
        [self.scrollView setContentSize:CGSizeMake(self.scrollView.frame.size.width * 10, self.scrollView.frame.size.height)];
    }
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [self.scrollView setFrame:self.view.bounds];
    [self.scrollView setContentSize:CGSizeMake(self.scrollView.frame.size.width * 10, self.scrollView.frame.size.height)];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

- (void)willAnimateRotationToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration
{
    [super willAnimateRotationToInterfaceOrientation:toInterfaceOrientation duration:duration];
    [self.scrollView setFrame:self.view.bounds];
    [self.scrollView setContentSize:CGSizeMake(self.scrollView.frame.size.width * 10, self.scrollView.frame.size.height)];
}

- (void)handlePan:(UIPanGestureRecognizer *)gestureRecognizer
{
    
    CGFloat xVelocity = [gestureRecognizer velocityInView:self.view].x;
    CGFloat xOffset = [gestureRecognizer translationInView:self.view].x;
    
    if (gestureRecognizer.state == UIGestureRecognizerStateEnded || gestureRecognizer.state == UIGestureRecognizerStateFailed) {
        [self.slidingMenuViewController finishCurrentStateActionWithVelocity:xVelocity];
    }
    else if (gestureRecognizer.state == UIGestureRecognizerStateChanged) {
    
        CGFloat translatedOffset = xOffset;
        
        if (xVelocity > 0) {
            
            if (xOffset + _menuOffsetWhenDragBegan > self.slidingMenuViewController.menuWidth) {
                translatedOffset = self.slidingMenuViewController.menuWidth;
            }
            
        }
        else {
            
            translatedOffset = _menuOffsetWhenDragBegan + xOffset;
            
        }
        
        // NSLog(@"xOffset: %02.2f, Translated: %02.2f", xOffset, translatedOffset);
        
        [self.slidingMenuViewController setContentOffset:translatedOffset withVelocity:xVelocity];
        
    }
    else if (gestureRecognizer.state == UIGestureRecognizerStateBegan) {
        _menuOffsetWhenDragBegan = self.slidingMenuViewController.currentContentOffset;
    }
    
}

#pragma mark - UIScrollViewDelegate

- (void)scrollViewDidScroll:(UIScrollView *)scrollView
{
    
    if (scrollView.contentOffset.x <= 0.0 && scrollView.isTracking) {
        
        if ([scrollView respondsToSelector:@selector(panGestureRecognizer)]) {
            
            CGFloat xVelocity = [scrollView.panGestureRecognizer velocityInView:self.scrollView].x;
            
            [self.slidingMenuViewController animateContentOffset:self.slidingMenuViewController.menuWidth withSpeed:(self.slidingMenuViewController.menuWidth/xVelocity)];
            
        }
        else {
            [self.slidingMenuViewController showMenu];
        }
        
    }

}
          
@end
